@@ -419,7 +419,9 @@ def prepare_dashboard(target, templatepath):
     """
     Bootstrap a dashboard
     """
-    appname = prompt("appname>")
+
+    appname = os.path.basename(target)
+    appdesc = prompt("app description>")
 
     templatedir = os.path.join(target, "templates", appname)
     try:
@@ -435,6 +437,7 @@ def prepare_dashboard(target, templatepath):
     for f in files:
         content = open(f).read()
         content = content.replace("APPNAME", appname)
+        content = content.replace("APPDESC", appdesc)
         basename = os.path.basename(f)
         targetfile = os.path.join(target, basename)
         with open(targetfile, "w") as fd:
@@ -453,13 +456,20 @@ def prepare_dashboard(target, templatepath):
             fd.write(content)
         print(basename, "=>", targetfile)
 
-    print("Add the following to the enrich.json applications")
+    print("Add the following to the enrich.json")
     print(
         json.dumps(
             {
-                "url": f"{appname}:index",
-                "description": "Update me",
-                "name": f"{appname.title()}",
+                "installed_apps": [
+                    f"{appname}.apps.{appname}Config"
+                ],
+                "applications": [
+                    {
+                        "url": f"{appname}:index",
+                        "description": "Update me",
+                        "name": f"{appname.title()}"
+                    }
+                ]
             },
             indent=4,
         )
