@@ -145,7 +145,7 @@ def _start(commands):
         {
             "cmd": [
                 "#To handle python paths etc. avoid spaces and hyphen in the names",
-                "git checkout git@github.com:alphainc/enrich-acme.git acme",
+                "git clone https://github.com/pingali/enrich-acme.git acme",
             ],
             "description": "GIT checkout a code repository",
         },
